# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`sensu`](#sensu): Base Sensu class
* [`sensu::agent`](#sensuagent): Manage Sensu agent
* [`sensu::api`](#sensuapi): Manage Sensu API
* [`sensu::backend`](#sensubackend): Manage Sensu backend
* [`sensu::cli`](#sensucli): Manage Sensu CLI
* [`sensu::plugins`](#sensuplugins): Manage Sensu plugins
* [`sensu::resources`](#sensuresources): Define sensu resources

#### Private Classes

* `sensu::backend::agent_resources`: Default sensu agent resources
* `sensu::backend::datastore::postgresql`: Manage Sensu backend PostgreSQL datastore
* `sensu::backend::default_resources`: Default sensu resources
* `sensu::common`: Sensu class for common resources
* `sensu::repo`: Private class to manage sensu repository resources
* `sensu::repo::community`: Private class to manage sensu community repository resources
* `sensu::ssl`: Private class to manage sensu SSL resources

### Defined types

* [`sensu::agent::annotation`](#sensuagentannotation): Add agent annotation
* [`sensu::agent::config_entry`](#sensuagentconfig_entry)
* [`sensu::agent::label`](#sensuagentlabel): Add agent label
* [`sensu::agent::subscription`](#sensuagentsubscription): Add agent subscription

### Resource types

* [`sensu_ad_auth`](#sensu_ad_auth): Manages Sensu AD auth.
* [`sensu_agent_entity_config`](#sensu_agent_entity_config): Manages a Sensu agent subscription
* [`sensu_agent_entity_setup`](#sensu_agent_entity_setup): Abstract type to configure other types
* [`sensu_agent_entity_validator`](#sensu_agent_entity_validator): **NOTE** This is a private type not intended to be used directly.  Verify the specified agent entity exists.
* [`sensu_api_config`](#sensu_api_config): Abstract type to configure other types
* [`sensu_api_validator`](#sensu_api_validator): **NOTE** This is a private type not intended to be used directly.  Verify that a connection can be successfully established between a node an
* [`sensu_asset`](#sensu_asset): Manages Sensu assets
* [`sensu_bonsai_asset`](#sensu_bonsai_asset): Manages Sensu Bonsai assets
* [`sensu_check`](#sensu_check): Manages Sensu checks
* [`sensu_cluster_federation`](#sensu_cluster_federation): Manages Sensu clusters federation
* [`sensu_cluster_federation_member`](#sensu_cluster_federation_member): Manages Sensu clusters federation member
* [`sensu_cluster_member`](#sensu_cluster_member): Manages Sensu cluster members
* [`sensu_cluster_role`](#sensu_cluster_role): Manages Sensu cluster roles
* [`sensu_cluster_role_binding`](#sensu_cluster_role_binding): Manages Sensu cluster role bindings
* [`sensu_command`](#sensu_command): Manage sensuctl command resources
* [`sensu_entity`](#sensu_entity): Manages Sensu entities
* [`sensu_etcd_replicator`](#sensu_etcd_replicator): Manages Sensu etcd replicators
* [`sensu_filter`](#sensu_filter): Manages Sensu filters
* [`sensu_handler`](#sensu_handler): Manages Sensu handlers
* [`sensu_hook`](#sensu_hook): Manages Sensu hooks
* [`sensu_ldap_auth`](#sensu_ldap_auth): Manages Sensu LDAP auth.
* [`sensu_license`](#sensu_license): Manage a sensu license
* [`sensu_mutator`](#sensu_mutator): Manages Sensu mutators
* [`sensu_namespace`](#sensu_namespace): Manages Sensu namespaces
* [`sensu_oidc_auth`](#sensu_oidc_auth): Manages Sensu OIDC auth.
* [`sensu_plugin`](#sensu_plugin): Manages Sensu plugins
* [`sensu_postgres_config`](#sensu_postgres_config): Manages Sensu postgres config
* [`sensu_resources`](#sensu_resources): Metatype for sensu resources
* [`sensu_role`](#sensu_role): Manages Sensu roles
* [`sensu_role_binding`](#sensu_role_binding): Manages Sensu role bindings
* [`sensu_secret`](#sensu_secret): Manages Sensu Secrets
* [`sensu_secrets_vault_provider`](#sensu_secrets_vault_provider): Manages Sensu Secrets provider
* [`sensu_tessen`](#sensu_tessen): Manages Sensu Tessen
* [`sensu_user`](#sensu_user): Manages Sensu users
* [`sensuctl_config`](#sensuctl_config): Abstract type to configure other types
* [`sensuctl_configure`](#sensuctl_configure): Manages 'sensuctl configure'

### Data types

* [`Sensu::Backend_URL`](#sensubackend_url): Sensu Backend URL's require protocol of ws:// or wss://. A port is also required. There is logic in sensu::agent class to add the protocol so

### Tasks

* [`agent_event`](#agent_event): Create a Sensu Go agent event via the agent API
* [`apikey`](#apikey): Manage Sensu Go API keys
* [`assets_outdated`](#assets_outdated): Retreive outdated Sensu Go assets
* [`backend_upgrade`](#backend_upgrade): Execute Sensu Go backend upgrade
* [`check_execute`](#check_execute): Execute a Sensu Go check
* [`event`](#event): Manage Sensu Go events
* [`install_agent`](#install_agent): Install Sensu Go agent
* [`install_agent_linux`](#install_agent_linux): Install Sensu Go agent on Linux
* [`install_agent_windows`](#install_agent_windows): Install Sensu Go agent on Windows
* [`resolve_reference`](#resolve_reference): Generate targets from Sensu Go
* [`silenced`](#silenced): Manage Sensu Go silencings

## Classes

### <a name="sensu"></a>`sensu`

This is the main Sensu class

#### Parameters

The following parameters are available in the `sensu` class:

* [`version`](#version)
* [`etc_dir`](#etc_dir)
* [`ssl_dir`](#ssl_dir)
* [`manage_user`](#manage_user)
* [`user`](#user)
* [`manage_group`](#manage_group)
* [`group`](#group)
* [`etc_dir_purge`](#etc_dir_purge)
* [`ssl_dir_purge`](#ssl_dir_purge)
* [`manage_repo`](#manage_repo)
* [`use_ssl`](#use_ssl)
* [`ssl_ca_source`](#ssl_ca_source)
* [`ssl_ca_content`](#ssl_ca_content)
* [`api_host`](#api_host)
* [`api_port`](#api_port)
* [`password`](#password)
* [`agent_password`](#agent_password)
* [`agent_entity_config_password`](#agent_entity_config_password)
* [`validate_namespaces`](#validate_namespaces)

##### <a name="version"></a>`version`

Data type: `String`

Version of Sensu to install.  Defaults to `installed` to support
Windows MSI packaging and to avoid surprising upgrades.

Default value: `'installed'`

##### <a name="etc_dir"></a>`etc_dir`

Data type: `Stdlib::Absolutepath`

Absolute path to the Sensu etc directory.

Default value: `'/etc/sensu'`

##### <a name="ssl_dir"></a>`ssl_dir`

Data type: `Stdlib::Absolutepath`

Absolute path to the Sensu ssl directory.

Default value: `'/etc/sensu/ssl'`

##### <a name="manage_user"></a>`manage_user`

Data type: `Boolean`

Boolean that determines if sensu user should be managed

Default value: ``true``

##### <a name="user"></a>`user`

Data type: `String`

User used by sensu services

Default value: `'sensu'`

##### <a name="manage_group"></a>`manage_group`

Data type: `Boolean`

Boolean that determines if sensu group should be managed

Default value: ``true``

##### <a name="group"></a>`group`

Data type: `String`

User group used by sensu services

Default value: `'sensu'`

##### <a name="etc_dir_purge"></a>`etc_dir_purge`

Data type: `Boolean`

Boolean to determine if the etc_dir should be purged
such that only Puppet managed files are present.

Default value: ``true``

##### <a name="ssl_dir_purge"></a>`ssl_dir_purge`

Data type: `Boolean`

Boolean to determine if the ssl_dir should be purged
such that only Puppet managed files are present.

Default value: ``true``

##### <a name="manage_repo"></a>`manage_repo`

Data type: `Boolean`

Boolean to determine if software repository for Sensu
should be managed.

Default value: ``true``

##### <a name="use_ssl"></a>`use_ssl`

Data type: `Boolean`

Sensu backend service uses SSL

Default value: ``true``

##### <a name="ssl_ca_source"></a>`ssl_ca_source`

Data type: `Optional[String]`

Source of SSL CA used by sensu services
This parameter is mutually exclusive with ssl_ca_content

Default value: `$facts['puppet_localcacert']`

##### <a name="ssl_ca_content"></a>`ssl_ca_content`

Data type: `Optional[String]`

Content of SSL CA used by sensu services
This parameter is mutually exclusive with ssl_ca_source

Default value: ``undef``

##### <a name="api_host"></a>`api_host`

Data type: `String`

Sensu backend host used to configure sensuctl and verify API access.

Default value: `$trusted['certname']`

##### <a name="api_port"></a>`api_port`

Data type: `Stdlib::Port`

Sensu backend port used to configure sensuctl and verify API access.

Default value: `8080`

##### <a name="password"></a>`password`

Data type: `String`

Sensu backend admin password used to confiure sensuctl.

Default value: `'P@ssw0rd!'`

##### <a name="agent_password"></a>`agent_password`

Data type: `String`

The sensu agent password

Default value: `'P@ssw0rd!'`

##### <a name="agent_entity_config_password"></a>`agent_entity_config_password`

Data type: `Optional[String]`

The password used when configuring Sensu Agent entity config items
Defaults to value used for `agent_password`.

Default value: ``undef``

##### <a name="validate_namespaces"></a>`validate_namespaces`

Data type: `Boolean`

Determines if sensuctl and sensu_api types will validate their namespace exists

Default value: ``true``

### <a name="sensuagent"></a>`sensu::agent`

Class to manage the Sensu agent.

#### Examples

##### 

```puppet
class { 'sensu::agent':
  backends      => ['sensu-backend.example.com:8081'],
  subscriptions => ['linux', 'apache-servers'],
  config_hash   => {
    'log-level' => 'info',
  },
}
```

#### Parameters

The following parameters are available in the `sensu::agent` class:

* [`version`](#version)
* [`package_source`](#package_source)
* [`package_download_path`](#package_download_path)
* [`package_name`](#package_name)
* [`service_env_vars_file`](#service_env_vars_file)
* [`service_env_vars`](#service_env_vars)
* [`service_name`](#service_name)
* [`service_ensure`](#service_ensure)
* [`service_enable`](#service_enable)
* [`service_path`](#service_path)
* [`config_hash`](#config_hash)
* [`agent_managed_entity`](#agent_managed_entity)
* [`backends`](#backends)
* [`entity_name`](#entity_name)
* [`subscriptions`](#subscriptions)
* [`annotations`](#annotations)
* [`labels`](#labels)
* [`namespace`](#namespace)
* [`redact`](#redact)
* [`show_diff`](#show_diff)
* [`log_file`](#log_file)
* [`agent_entity_config_provider`](#agent_entity_config_provider)

##### <a name="version"></a>`version`

Data type: `Optional[String]`

Version of sensu agent to install.  Defaults to `installed` to support
Windows MSI packaging and to avoid surprising upgrades.

Default value: ``undef``

##### <a name="package_source"></a>`package_source`

Data type: `Optional[String[1]]`

Source of package for installing Windows.
Paths with http:// or https:// will be downloaded
Paths with puppet:// or absolute filesystem paths will also be installed.

Default value: ``undef``

##### <a name="package_download_path"></a>`package_download_path`

Data type: `Optional[Stdlib::Absolutepath]`

Where to download the MSI for Windows. Defaults to `C:\`.
This parameter only used when `package_source` is an URL or when it's a puppet source (`puppet://`).

Default value: ``undef``

##### <a name="package_name"></a>`package_name`

Data type: `String`

Name of Sensu agent package.

Default value: `'sensu-go-agent'`

##### <a name="service_env_vars_file"></a>`service_env_vars_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to the agent service ENV variables file.
Debian based default: `/etc/default/sensu-agent`
RedHat based default: `/etc/sysconfig/sensu-agent`

Default value: ``undef``

##### <a name="service_env_vars"></a>`service_env_vars`

Data type: `Hash`

Hash of environment variables loaded by sensu-agent service

Default value: `{}`

##### <a name="service_name"></a>`service_name`

Data type: `String`

Name of the Sensu agent service.

Default value: `'sensu-agent'`

##### <a name="service_ensure"></a>`service_ensure`

Data type: `String`

Sensu agent service ensure value.

Default value: `'running'`

##### <a name="service_enable"></a>`service_enable`

Data type: `Boolean`

Sensu agent service enable value.

Default value: ``true``

##### <a name="service_path"></a>`service_path`

Data type: `Stdlib::Absolutepath`

The path to sensu-agent service executable

Default value: `'/usr/sbin/sensu-agent'`

##### <a name="config_hash"></a>`config_hash`

Data type: `Hash`

Sensu agent configuration hash used to define agent.yml.

Default value: `{}`

##### <a name="agent_managed_entity"></a>`agent_managed_entity`

Data type: `Boolean`

Manage agent entity using agent.yml rather than API

Default value: ``false``

##### <a name="backends"></a>`backends`

Data type: `Optional[Array[Sensu::Backend_URL]]`

Array of sensu backends to pass to `backend-url` config option.
Default is `["${sensu::api_host}:8081"]`
The protocol prefix of `ws://` or `wss://` are optional and will be determined
based on `sensu::use_ssl` parameter by default.
Passing `backend-url` as part of `config_hash` takes precedence over this parameter.

Default value: ``undef``

##### <a name="entity_name"></a>`entity_name`

Data type: `String[1]`

The value for agent.yml `name`.
Passing `name` as part of `config_hash` takes precedence

Default value: `$facts['networking']['fqdn']`

##### <a name="subscriptions"></a>`subscriptions`

Data type: `Optional[Array[String[1]]]`

The agent subscriptions to define in agent.yml
Passing `subscriptions` as part of `config_hash` takes precedence

Default value: ``undef``

##### <a name="annotations"></a>`annotations`

Data type: `Optional[Hash[String[1],String]]`

The agent annotations value for agent.yml
Passing `annotations` as part of `config_hash` takes precedence

Default value: ``undef``

##### <a name="labels"></a>`labels`

Data type: `Optional[Hash[String[1],String]]`

The agent labels value for agent.yml
Passing `labels` as part of `config_hash` takes precedence

Default value: ``undef``

##### <a name="namespace"></a>`namespace`

Data type: `String[1]`

The agent namespace
Passing `namespace` as part of `config_hash` takes precedence

Default value: `'default'`

##### <a name="redact"></a>`redact`

Data type: `Array[String[1]]`

The agent entity redact list
Passing `redact` as part of `config_hash` takes precedence
Defaults come from Sensu documentation:
https://docs.sensu.io/sensu-go/latest/reference/agent/#security-configuration-flags

Default value: `['password','passwd','pass','api_key','api_token','access_key','secret_key','private_key','secret']`

##### <a name="show_diff"></a>`show_diff`

Data type: `Boolean`

Sets show_diff parameter for agent.yml configuration file

Default value: ``true``

##### <a name="log_file"></a>`log_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to agent log file, only for Windows.
Defaults to `C:\ProgramData\sensu\log\sensu-agent.log`

Default value: ``undef``

##### <a name="agent_entity_config_provider"></a>`agent_entity_config_provider`

Data type: `Enum['sensuctl','sensu_api']`

The provider to use when managing sensu_agent_entity_config resources

Default value: `'sensu_api'`

### <a name="sensuapi"></a>`sensu::api`

Class to manage the Sensu API.

#### Examples

##### 

```puppet
include sensu::api
```

### <a name="sensubackend"></a>`sensu::backend`

Class to manage the Sensu backend.

#### Examples

##### 

```puppet
include sensu::backend
```

#### Parameters

The following parameters are available in the `sensu::backend` class:

* [`version`](#version)
* [`package_name`](#package_name)
* [`service_env_vars_file`](#service_env_vars_file)
* [`service_env_vars`](#service_env_vars)
* [`service_name`](#service_name)
* [`service_ensure`](#service_ensure)
* [`service_enable`](#service_enable)
* [`service_path`](#service_path)
* [`state_dir`](#state_dir)
* [`config_hash`](#config_hash)
* [`ssl_cert_source`](#ssl_cert_source)
* [`ssl_cert_content`](#ssl_cert_content)
* [`ssl_key_source`](#ssl_key_source)
* [`ssl_key_content`](#ssl_key_content)
* [`include_default_resources`](#include_default_resources)
* [`include_agent_resources`](#include_agent_resources)
* [`manage_agent_user`](#manage_agent_user)
* [`agent_user_disabled`](#agent_user_disabled)
* [`show_diff`](#show_diff)
* [`license_source`](#license_source)
* [`license_content`](#license_content)
* [`manage_tessen`](#manage_tessen)
* [`tessen_ensure`](#tessen_ensure)
* [`datastore`](#datastore)
* [`datastore_ensure`](#datastore_ensure)
* [`manage_postgresql_db`](#manage_postgresql_db)
* [`postgresql_name`](#postgresql_name)
* [`postgresql_user`](#postgresql_user)
* [`postgresql_password`](#postgresql_password)
* [`postgresql_host`](#postgresql_host)
* [`postgresql_port`](#postgresql_port)
* [`postgresql_dbname`](#postgresql_dbname)
* [`postgresql_sslmode`](#postgresql_sslmode)
* [`postgresql_ssl_dir`](#postgresql_ssl_dir)
* [`postgresql_ssl_ca_source`](#postgresql_ssl_ca_source)
* [`postgresql_ssl_ca_content`](#postgresql_ssl_ca_content)
* [`postgresql_ssl_crl_source`](#postgresql_ssl_crl_source)
* [`postgresql_ssl_crl_content`](#postgresql_ssl_crl_content)
* [`postgresql_ssl_cert_source`](#postgresql_ssl_cert_source)
* [`postgresql_ssl_cert_content`](#postgresql_ssl_cert_content)
* [`postgresql_ssl_key_source`](#postgresql_ssl_key_source)
* [`postgresql_ssl_key_content`](#postgresql_ssl_key_content)
* [`postgresql_pool_size`](#postgresql_pool_size)
* [`postgresql_strict`](#postgresql_strict)
* [`postgresql_batch_buffer`](#postgresql_batch_buffer)
* [`postgresql_batch_size`](#postgresql_batch_size)
* [`postgresql_batch_workers`](#postgresql_batch_workers)
* [`postgresql_enable_round_robin`](#postgresql_enable_round_robin)

##### <a name="version"></a>`version`

Data type: `Optional[String]`

Version of sensu backend to install.  Defaults to `installed` to support
Windows MSI packaging and to avoid surprising upgrades.

Default value: ``undef``

##### <a name="package_name"></a>`package_name`

Data type: `String`

Name of Sensu backend package.

Default value: `'sensu-go-backend'`

##### <a name="service_env_vars_file"></a>`service_env_vars_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to the backend service ENV variables file.
Debian based default: `/etc/default/sensu-backend`
RedHat based default: `/etc/sysconfig/sensu-backend`

Default value: ``undef``

##### <a name="service_env_vars"></a>`service_env_vars`

Data type: `Hash`

Hash of environment variables loaded by sensu-backend service

Default value: `{}`

##### <a name="service_name"></a>`service_name`

Data type: `String`

Name of the Sensu backend service.

Default value: `'sensu-backend'`

##### <a name="service_ensure"></a>`service_ensure`

Data type: `String`

Sensu backend service ensure value.

Default value: `'running'`

##### <a name="service_enable"></a>`service_enable`

Data type: `Boolean`

Sensu backend service enable value.

Default value: ``true``

##### <a name="service_path"></a>`service_path`

Data type: `Stdlib::Absolutepath`

The path to sensu-backend service executable

Default value: `'/usr/sbin/sensu-backend'`

##### <a name="state_dir"></a>`state_dir`

Data type: `Stdlib::Absolutepath`

Sensu backend state directory path.

Default value: `'/var/lib/sensu/sensu-backend'`

##### <a name="config_hash"></a>`config_hash`

Data type: `Hash`

Sensu backend configuration hash used to define backend.yml.

Default value: `{}`

##### <a name="ssl_cert_source"></a>`ssl_cert_source`

Data type: `Optional[String]`

The SSL certificate source
This parameter is mutually exclusive with ssl_cert_content

Default value: `$facts['puppet_hostcert']`

##### <a name="ssl_cert_content"></a>`ssl_cert_content`

Data type: `Optional[String]`

The SSL certificate content
This parameter is mutually exclusive with ssl_cert_source

Default value: ``undef``

##### <a name="ssl_key_source"></a>`ssl_key_source`

Data type: `Optional[String]`

The SSL private key source
This parameter is mutually exclusive with ssl_key_content

Default value: `$facts['puppet_hostprivkey']`

##### <a name="ssl_key_content"></a>`ssl_key_content`

Data type: `Optional[String]`

The SSL private key content
This parameter is mutually exclusive with ssl_key_source

Default value: ``undef``

##### <a name="include_default_resources"></a>`include_default_resources`

Data type: `Boolean`

Sets if default sensu resources should be included

Default value: ``true``

##### <a name="include_agent_resources"></a>`include_agent_resources`

Data type: `Boolean`

Sets if agent RBAC resources should be included

Default value: ``true``

##### <a name="manage_agent_user"></a>`manage_agent_user`

Data type: `Boolean`

Sets if the Sensu agent user should be managed

Default value: ``true``

##### <a name="agent_user_disabled"></a>`agent_user_disabled`

Data type: `Boolean`

Sets if the Sensu agent user should be disabled
Not applicable if `manage_agent_user` is `false`
This is useful if using agent TLS authentication
See https://docs.sensu.io/sensu-go/latest/guides/securing-sensu/#sensu-agent-tls-authentication

Default value: ``false``

##### <a name="show_diff"></a>`show_diff`

Data type: `Boolean`

Sets show_diff parameter for backend.yml configuration file

Default value: ``true``

##### <a name="license_source"></a>`license_source`

Data type: `Optional[String]`

The source of sensu-go enterprise license.
Supports any valid Puppet File sources such as absolute paths or puppet:///
Do not define with license_content

Default value: ``undef``

##### <a name="license_content"></a>`license_content`

Data type: `Optional[String]`

The content of sensu-go enterprise license
Do not define with license_source

Default value: ``undef``

##### <a name="manage_tessen"></a>`manage_tessen`

Data type: `Boolean`

Boolean that determines if Tessen is managed

Default value: ``true``

##### <a name="tessen_ensure"></a>`tessen_ensure`

Data type: `Enum['present','absent']`

Determine if Tessen is opt-in (present) or opt-out (absent)

Default value: `'present'`

##### <a name="datastore"></a>`datastore`

Data type: `Optional[Enum['postgresql']]`

Datastore to configure for sensu events

Default value: ``undef``

##### <a name="datastore_ensure"></a>`datastore_ensure`

Data type: `Enum['present','absent']`

The datastore ensure property. If set to `absent` all
datastore parameters must still be defined.

Default value: `'present'`

##### <a name="manage_postgresql_db"></a>`manage_postgresql_db`

Data type: `Boolean`

Boolean that sets of postgresql database should be managed

Default value: ``true``

##### <a name="postgresql_name"></a>`postgresql_name`

Data type: `String`

Name of PostgresConfig that is configured with sensuctl

Default value: `'postgresql'`

##### <a name="postgresql_user"></a>`postgresql_user`

Data type: `String`

The PostgreSQL database user

Default value: `'sensu'`

##### <a name="postgresql_password"></a>`postgresql_password`

Data type: `String`

The PostgreSQL database password

Default value: `'changeme'`

##### <a name="postgresql_host"></a>`postgresql_host`

Data type: `Stdlib::Host`

The PostgreSQL host

Default value: `'localhost'`

##### <a name="postgresql_port"></a>`postgresql_port`

Data type: `Stdlib::Port`

The PostgreSQL port

Default value: `5432`

##### <a name="postgresql_dbname"></a>`postgresql_dbname`

Data type: `String`

The name of the PostgreSQL database

Default value: `'sensu'`

##### <a name="postgresql_sslmode"></a>`postgresql_sslmode`

Data type: `Enum['disable','require','verify-ca','verify-full']`

The PostgreSQL sslmode value

Default value: `'require'`

##### <a name="postgresql_ssl_dir"></a>`postgresql_ssl_dir`

Data type: `Stdlib::Absolutepath`

The path to store SSL related files for PostgreSQL connections

Default value: `'/var/lib/sensu/.postgresql'`

##### <a name="postgresql_ssl_ca_source"></a>`postgresql_ssl_ca_source`

Data type: `Optional[String]`

The source of PostgreSQL SSL CA
Do not define with postgresql_ssl_ca_content

Default value: ``undef``

##### <a name="postgresql_ssl_ca_content"></a>`postgresql_ssl_ca_content`

Data type: `Optional[String]`

The content of PostgreSQL SSL CA
Do not define with postgresql_ssl_ca_source

Default value: ``undef``

##### <a name="postgresql_ssl_crl_source"></a>`postgresql_ssl_crl_source`

Data type: `Optional[String]`

The source of PostgreSQL SSL CRL
Do not define with postgresql_ssl_crl_content

Default value: ``undef``

##### <a name="postgresql_ssl_crl_content"></a>`postgresql_ssl_crl_content`

Data type: `Optional[String]`

The content of PostgreSQL SSL CRL
Do not define with postgresql_ssl_crl_source

Default value: ``undef``

##### <a name="postgresql_ssl_cert_source"></a>`postgresql_ssl_cert_source`

Data type: `Optional[String]`

The source of PostgreSQL SSL certificate
Do not define with postgresql_ssl_cert_content

Default value: ``undef``

##### <a name="postgresql_ssl_cert_content"></a>`postgresql_ssl_cert_content`

Data type: `Optional[String]`

The content of PostgreSQL SSL certificate
Do not define with postgresql_ssl_cert_source

Default value: ``undef``

##### <a name="postgresql_ssl_key_source"></a>`postgresql_ssl_key_source`

Data type: `Optional[String]`

The source of PostgreSQL SSL private key
Do not define with postgresql_ssl_key_content

Default value: ``undef``

##### <a name="postgresql_ssl_key_content"></a>`postgresql_ssl_key_content`

Data type: `Optional[String]`

The content of PostgreSQL SSL private key
Do not define with postgresql_ssl_key_source

Default value: ``undef``

##### <a name="postgresql_pool_size"></a>`postgresql_pool_size`

Data type: `Integer`

The PostgreSQL pool size

Default value: `20`

##### <a name="postgresql_strict"></a>`postgresql_strict`

Data type: `Boolean`

Enables strict configuration checks for PostgreSQL

Default value: ``false``

##### <a name="postgresql_batch_buffer"></a>`postgresql_batch_buffer`

Data type: `Integer`

PostgreSQL batch buffer size

Default value: `0`

##### <a name="postgresql_batch_size"></a>`postgresql_batch_size`

Data type: `Integer`

PostgreSQL batch size

Default value: `1`

##### <a name="postgresql_batch_workers"></a>`postgresql_batch_workers`

Data type: `Integer`

PostgreSQL batch workers

Default value: `20`

##### <a name="postgresql_enable_round_robin"></a>`postgresql_enable_round_robin`

Data type: `Boolean`

PostgreSQL enable round robin

Default value: ``false``

### <a name="sensucli"></a>`sensu::cli`

Class to manage the Sensu CLI.

#### Examples

##### 

```puppet
class { 'sensu::cli':
  password => 'secret',
}
```

#### Parameters

The following parameters are available in the `sensu::cli` class:

* [`version`](#version)
* [`package_name`](#package_name)
* [`install_source`](#install_source)
* [`install_path`](#install_path)
* [`configure`](#configure)
* [`sensuctl_chunk_size`](#sensuctl_chunk_size)
* [`config_format`](#config_format)
* [`config_namespace`](#config_namespace)

##### <a name="version"></a>`version`

Data type: `Optional[String]`

Version of sensu-go-cli to install.  Defaults to `installed` to support
Windows MSI packaging and to avoid surprising upgrades.

Default value: ``undef``

##### <a name="package_name"></a>`package_name`

Data type: `String`

Name of Sensu CLI package.

Default value: `'sensu-go-cli'`

##### <a name="install_source"></a>`install_source`

Data type: `Optional[Variant[Stdlib::HTTPSUrl, Stdlib::HTTPUrl, Pattern[/^(file|puppet):/]]]`

Source of Sensu Go CLI download for installing on Windows.
Paths with http:// or https:// will be downloaded
Paths with puppet:// or file:// paths will also be installed.

Default value: ``undef``

##### <a name="install_path"></a>`install_path`

Data type: `Optional[Stdlib::Absolutepath]`

Where to install sensuctl for Windows. Default to `C:\Program Files\Sensu`.

Default value: ``undef``

##### <a name="configure"></a>`configure`

Data type: `Boolean`

Determines if sensuctl should be configured

Default value: ``true``

##### <a name="sensuctl_chunk_size"></a>`sensuctl_chunk_size`

Data type: `Optional[Integer]`

Chunk size to use when listing sensuctl resources

Default value: ``undef``

##### <a name="config_format"></a>`config_format`

Data type: `Optional[Enum['tabular','json','wrapped-json','yaml']]`

Default format for sensuctl

Default value: ``undef``

##### <a name="config_namespace"></a>`config_namespace`

Data type: `Optional[String]`

Default namespace for sensuctl

Default value: ``undef``

### <a name="sensuplugins"></a>`sensu::plugins`

Class to manage the Sensu plugins.

#### Examples

##### 

```puppet
class { 'sensu::plugins':
  plugins    => ['disk-checks'],
  extensions => ['graphite'],
}
```

##### 

```puppet
class { 'sensu::plugins':
  plugins    => {
    'disk-checks' => { 'version' => 'latest' },
  },
  extensions => {
    'graphite' => { 'version' => 'latest' },
  },
}
```

#### Parameters

The following parameters are available in the `sensu::plugins` class:

* [`manage_repo`](#manage_repo)
* [`package_ensure`](#package_ensure)
* [`package_name`](#package_name)
* [`dependencies`](#dependencies)
* [`gem_dependencies`](#gem_dependencies)
* [`plugins`](#plugins)
* [`extensions`](#extensions)

##### <a name="manage_repo"></a>`manage_repo`

Data type: `Optional[Boolean]`

Determines if plugin repo should be managed.
Defaults to value for `sensu::manage_repo`.

Default value: ``undef``

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String`

Ensure property for sensu plugins package.

Default value: `'installed'`

##### <a name="package_name"></a>`package_name`

Data type: `String`

Name of the Sensu plugins ruby package.

Default value: `'sensu-plugins-ruby'`

##### <a name="dependencies"></a>`dependencies`

Data type: `Array`

Package dependencies needed to install plugins and extensions.
Default is OS dependent.

Default value: `[]`

##### <a name="gem_dependencies"></a>`gem_dependencies`

Data type: `Array`

Gem dependencies.

Default value: `[]`

##### <a name="plugins"></a>`plugins`

Data type: `Variant[Array, Hash]`

Plugins to install

Default value: `[]`

##### <a name="extensions"></a>`extensions`

Data type: `Variant[Array, Hash]`

Extensions to install

Default value: `[]`

### <a name="sensuresources"></a>`sensu::resources`

Define sensu resources

#### Parameters

The following parameters are available in the `sensu::resources` class:

* [`ad_auths`](#ad_auths)
* [`assets`](#assets)
* [`bonsai_assets`](#bonsai_assets)
* [`checks`](#checks)
* [`cluster_federations`](#cluster_federations)
* [`cluster_federation_members`](#cluster_federation_members)
* [`cluster_members`](#cluster_members)
* [`cluster_role_bindings`](#cluster_role_bindings)
* [`cluster_roles`](#cluster_roles)
* [`configs`](#configs)
* [`entities`](#entities)
* [`etcd_replicators`](#etcd_replicators)
* [`filters`](#filters)
* [`handlers`](#handlers)
* [`hooks`](#hooks)
* [`ldap_auths`](#ldap_auths)
* [`mutators`](#mutators)
* [`namespaces`](#namespaces)
* [`oidc_auths`](#oidc_auths)
* [`role_bindings`](#role_bindings)
* [`roles`](#roles)
* [`secrets`](#secrets)
* [`secrets_vault_providers`](#secrets_vault_providers)
* [`users`](#users)

##### <a name="ad_auths"></a>`ad_auths`

Data type: `Hash`

Hash of sensu_ad_auth resources

Default value: `{}`

##### <a name="assets"></a>`assets`

Data type: `Hash`

Hash of sensu_asset resources

Default value: `{}`

##### <a name="bonsai_assets"></a>`bonsai_assets`

Data type: `Hash`

Hash of sensu_bonsai_asset resources

Default value: `{}`

##### <a name="checks"></a>`checks`

Data type: `Hash`

Hash of sensu_check resources

Default value: `{}`

##### <a name="cluster_federations"></a>`cluster_federations`

Data type: `Hash`

Hash of sensu_cluster_federation resources

Default value: `{}`

##### <a name="cluster_federation_members"></a>`cluster_federation_members`

Data type: `Hash`

Hash of sensu_cluster_federation_member resources

Default value: `{}`

##### <a name="cluster_members"></a>`cluster_members`

Data type: `Hash`

Hash of sensu_cluster_member resources

Default value: `{}`

##### <a name="cluster_role_bindings"></a>`cluster_role_bindings`

Data type: `Hash`

Hash of sensu_cluster_role_binding resources

Default value: `{}`

##### <a name="cluster_roles"></a>`cluster_roles`

Data type: `Hash`

Hash of sensu_cluster_role resources

Default value: `{}`

##### <a name="configs"></a>`configs`

Data type: `Hash`

Hash of sensu_config resources

Default value: `{}`

##### <a name="entities"></a>`entities`

Data type: `Hash`

Hash of sensu_entity resources

Default value: `{}`

##### <a name="etcd_replicators"></a>`etcd_replicators`

Data type: `Hash`

Hash of sensu_etcd_replicator resources

Default value: `{}`

##### <a name="filters"></a>`filters`

Data type: `Hash`

Hash of sensu_filter resources

Default value: `{}`

##### <a name="handlers"></a>`handlers`

Data type: `Hash`

Hash of sensu_handler resources

Default value: `{}`

##### <a name="hooks"></a>`hooks`

Data type: `Hash`

Hash of sensu_hook resources

Default value: `{}`

##### <a name="ldap_auths"></a>`ldap_auths`

Data type: `Hash`

Hash of sensu_ldap_auth resources

Default value: `{}`

##### <a name="mutators"></a>`mutators`

Data type: `Hash`

Hash of sensu_mutator resources

Default value: `{}`

##### <a name="namespaces"></a>`namespaces`

Data type: `Hash`

Hash of sensu_namespace resources

Default value: `{}`

##### <a name="oidc_auths"></a>`oidc_auths`

Data type: `Hash`

Hash of sensu_oidc_auth resources

Default value: `{}`

##### <a name="role_bindings"></a>`role_bindings`

Data type: `Hash`

Hash of sensu_role_binding resources

Default value: `{}`

##### <a name="roles"></a>`roles`

Data type: `Hash`

Hash of sensu_role resources

Default value: `{}`

##### <a name="secrets"></a>`secrets`

Data type: `Hash`

Hash of secrets

Default value: `{}`

##### <a name="secrets_vault_providers"></a>`secrets_vault_providers`

Data type: `Hash`

Hash of sensu_secrets_vault_providers

Default value: `{}`

##### <a name="users"></a>`users`

Data type: `Hash`

Hash of sensu_user resources

Default value: `{}`

## Defined types

### <a name="sensuagentannotation"></a>`sensu::agent::annotation`

Add agent annotation

#### Examples

##### 

```puppet
sensu::agent::annotation { 'fatigue_check/occurrences:': value => '2' }
```

#### Parameters

The following parameters are available in the `sensu::agent::annotation` defined type:

* [`ensure`](#ensure)
* [`key`](#key)
* [`value`](#value)
* [`redact`](#redact)
* [`order`](#order)
* [`entity`](#entity)
* [`namespace`](#namespace)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present','absent']`

Ensure property of the annotation

Default value: `'present'`

##### <a name="key"></a>`key`

Data type: `String[1]`

Key of the annotation to add to agent.yml, defaults to `$name`.

Default value: `$name`

##### <a name="value"></a>`value`

Data type: `String`

Label value to add to agent.yml

##### <a name="redact"></a>`redact`

Data type: `Boolean`

Boolean that sets if this entry should be added to redact list

Default value: ``false``

##### <a name="order"></a>`order`

Data type: `String[1]`

Order of the datacat fragment

Default value: `'50'`

##### <a name="entity"></a>`entity`

Data type: `Optional[String[1]]`

Entity where to manage this annotation

Default value: ``undef``

##### <a name="namespace"></a>`namespace`

Data type: `Optional[String[1]]`

Namespace of entity to manage this annotation

Default value: ``undef``

### <a name="sensuagentconfig_entry"></a>`sensu::agent::config_entry`

The sensu::agent::config_entry class.

#### Parameters

The following parameters are available in the `sensu::agent::config_entry` defined type:

* [`key`](#key)
* [`value`](#value)
* [`order`](#order)

##### <a name="key"></a>`key`

Data type: `String[1]`

Key of the config entry to add to agent.yml, defaults to `$name`.

Default value: `$name`

##### <a name="value"></a>`value`

Data type: `Any`

Config entry value to add to agent.yml

##### <a name="order"></a>`order`

Data type: `String[1]`

Order of the datacat fragment

Default value: `'50'`

### <a name="sensuagentlabel"></a>`sensu::agent::label`

Add agent label

#### Examples

##### 

```puppet
sensu::agent::label { 'contacts': value => 'ops@example.com' }
```

#### Parameters

The following parameters are available in the `sensu::agent::label` defined type:

* [`ensure`](#ensure)
* [`key`](#key)
* [`value`](#value)
* [`redact`](#redact)
* [`order`](#order)
* [`entity`](#entity)
* [`namespace`](#namespace)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Ensure property for the label

Default value: `'present'`

##### <a name="key"></a>`key`

Data type: `String[1]`

Key of the label to add to agent.yml, defaults to `$name`.

Default value: `$name`

##### <a name="value"></a>`value`

Data type: `String`

Label value to add to agent.yml

##### <a name="redact"></a>`redact`

Data type: `Boolean`

Boolean that sets if this entry should be added to redact list

Default value: ``false``

##### <a name="order"></a>`order`

Data type: `String[1]`

Order of the datacat fragment

Default value: `'50'`

##### <a name="entity"></a>`entity`

Data type: `Optional[String[1]]`

Entity where to manage this label

Default value: ``undef``

##### <a name="namespace"></a>`namespace`

Data type: `Optional[String[1]]`

Namespace of entity to manage this label

Default value: ``undef``

### <a name="sensuagentsubscription"></a>`sensu::agent::subscription`

Add agent subscription

#### Examples

##### 

```puppet
sensu::agent::subscription { 'mysql': }
```

#### Parameters

The following parameters are available in the `sensu::agent::subscription` defined type:

* [`subscription`](#subscription)
* [`order`](#order)
* [`entity`](#entity)
* [`namespace`](#namespace)

##### <a name="subscription"></a>`subscription`

Data type: `String[1]`

Name of the subscription to add to agent.yml, defaults to `$name`.

Default value: `$name`

##### <a name="order"></a>`order`

Data type: `String[1]`

Order of the datacat fragment

Default value: `'50'`

##### <a name="entity"></a>`entity`

Data type: `Optional[String[1]]`

Entity where to manage this subscription

Default value: ``undef``

##### <a name="namespace"></a>`namespace`

Data type: `Optional[String[1]]`

Namespace of entity to manage this subscription

Default value: ``undef``

## Resource types

### <a name="sensu_ad_auth"></a>`sensu_ad_auth`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`

#### Examples

##### Add a AD auth

```puppet
sensu_ldap_auth { 'ad':
  ensure              => 'present',
  servers             => [
    {
      'host' => '127.0.0.1',
      'port' => 389,
      'binding' => {
        'user_dn' => 'cn=binder,dc=acme,dc=org',
        'password' => 'P@ssw0rd!'
      },
      'group_search' => {
        'base_dn' => 'dc=acme,dc=org',
      },
      'user_search'  => {
        'base_dn' => 'dc=acme,dc=org',
      },
    },
  ],
}
```

##### Add an AD auth that uses memberOf attribute by omitting group_search

```puppet
sensu_ldap_auth { 'ad':
  ensure              => 'present',
  servers             => [
    {
      'host' => '127.0.0.1',
      'port' => 389,
      'binding' => {
        'user_dn' => 'cn=binder,dc=acme,dc=org',
        'password' => 'P@ssw0rd!'
      },
      'user_search'  => {
        'base_dn' => 'dc=acme,dc=org',
      },
    },
  ],
}
```

#### Properties

The following properties are available in the `sensu_ad_auth` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `groups_prefix`

The prefix added to all LDAP groups.

##### `servers`

AD servers as Array of Hashes

Keys:
* host: required
* port: required
* group_search: optional (omit to use memberOf)
* user_search: required
* binding: optional Hash
* insecure: default is `false`
* security: default is `tls`
* trusted_ca_file: default is `""`
* client_cert_file: default is `""`
* client_key_file: default is `""`
* default_upn_domain: default is `""`
* include_nested_groups: Boolean

group_search keys:
* base_dn: required
* attribute: default is `member`
* name_attribute: default is `cn`
* object_class: default is `group`

user_search Keys:
* base_dn: required
* attribute: default is `sAMAccountName`
* name_attribute: default is `displayName`
* object_class: default is `person`

binding keys:
* user_dn: required
* password: required

##### `username_prefix`

The prefix added to all LDAP usernames.

#### Parameters

The following parameters are available in the `sensu_ad_auth` type.

* [`name`](#name)
* [`provider`](#provider)

##### <a name="name"></a>`name`

namevar

The name of the AD auth.

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_ad_auth` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="sensu_agent_entity_config"></a>`sensu_agent_entity_config`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Service[sensu-agent]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.

#### Examples

##### Add a subscription to an agent using composite names

```puppet
sensu_agent_entity_config { 'subscription value linux on sensu-agent.example.org in dev':
  ensure => 'present',
}
```

##### Add an annotation to an agent using composite names

```puppet
sensu_agent_entity_config { 'annotations key contacts on sensu-agent.example.org in dev':
  ensure => 'present',
  value  => 'dev@example.com',
}
```

##### Add a subscription to an agent

```puppet
sensu_agent_entity_config { 'subscription':
  ensure    => 'present',
  config    => 'subscription',
  value     => 'linux',
  entity    => 'sensu-agent.example.org',
  namespace => 'dev',
}
```

##### Add an annotation to an agent

```puppet
sensu_agent_entity_config { 'annotation-contacts':
  ensure    => 'present',
  config    => 'annotation',
  key       => 'contacts',
  value     => 'dev@example.com',
  entity    => 'sensu-agent.example.org',
  namespace => 'dev',
}
```

#### Properties

The following properties are available in the `sensu_agent_entity_config` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `value`

The value of the config for agent entity

#### Parameters

The following parameters are available in the `sensu_agent_entity_config` type.

* [`agent_managed_entity`](#agent_managed_entity)
* [`config`](#config)
* [`entity`](#entity)
* [`key`](#key)
* [`name`](#name)
* [`namespace`](#namespace)
* [`provider`](#provider)

##### <a name="agent_managed_entity"></a>`agent_managed_entity`

Valid values: ``true``, ``false``

PRIVATE - determined by looking at agent entity labels

Default value: ``false``

##### <a name="config"></a>`config`

The name of the config to set.

##### <a name="entity"></a>`entity`

The entity to manage subscription

##### <a name="key"></a>`key`

Key of config entry set, for labels and annotations

##### <a name="name"></a>`name`

namevar

The name of the agent subscription.
The name supports composite names that can define the entity and namespace.
An example composite name to define subscription named `test` on entity 'agent' in namespace `dev`: `test on agent in
dev`

##### <a name="namespace"></a>`namespace`

The Sensu RBAC namespace that this entity belongs to.

Default value: `default`

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_agent_entity_config` resource. You will seldom need to specify this ---
Puppet will usually discover the appropriate provider for your platform.

### <a name="sensu_agent_entity_setup"></a>`sensu_agent_entity_setup`

**NOTE** This is a private type not intended to be used directly.

#### Parameters

The following parameters are available in the `sensu_agent_entity_setup` type.

* [`agent_managed_entity`](#agent_managed_entity)
* [`name`](#name)
* [`password`](#password)
* [`url`](#url)
* [`username`](#username)

##### <a name="agent_managed_entity"></a>`agent_managed_entity`

Valid values: ``true``, ``false``

Agent entity managed by agent.yml

Default value: ``false``

##### <a name="name"></a>`name`

namevar

The name of the resource.

##### <a name="password"></a>`password`

Sensu API password

##### <a name="url"></a>`url`

Sensu API URL

##### <a name="username"></a>`username`

Sensu API username

### <a name="sensu_agent_entity_validator"></a>`sensu_agent_entity_validator`

**NOTE** This is a private type not intended to be used directly.

Verify the specified agent entity exists.

#### Examples

##### Verify agent entity 'sensu-agent' exists

```puppet
sensu_api_validator { 'sensu-agent':
  namespace => 'dev',
}
```

#### Properties

The following properties are available in the `sensu_agent_entity_validator` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `sensu_agent_entity_validator` type.

* [`name`](#name)
* [`namespace`](#namespace)
* [`provider`](#provider)
* [`timeout`](#timeout)

##### <a name="name"></a>`name`

namevar

An entity to verify

##### <a name="namespace"></a>`namespace`

Namespace of entity

Default value: `default`

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_agent_entity_validator` resource. You will seldom need to specify this ---
Puppet will usually discover the appropriate provider for your platform.

##### <a name="timeout"></a>`timeout`

The max number of seconds that the validator should wait before giving up and deciding that entity does not exist

Default value: `10`

### <a name="sensu_api_config"></a>`sensu_api_config`

**NOTE** This is a private type not intended to be used directly.

#### Parameters

The following parameters are available in the `sensu_api_config` type.

* [`name`](#name)
* [`password`](#password)
* [`url`](#url)
* [`username`](#username)
* [`validate_namespaces`](#validate_namespaces)

##### <a name="name"></a>`name`

namevar

The name of the resource.

##### <a name="password"></a>`password`

Sensu API password

##### <a name="url"></a>`url`

Sensu API URL

##### <a name="username"></a>`username`

Sensu API username

##### <a name="validate_namespaces"></a>`validate_namespaces`

Valid values: ``true``, ``false``

Determines of namespaces should be validated with Sensu API

Default value: ``true``

### <a name="sensu_api_validator"></a>`sensu_api_validator`

**NOTE** This is a private type not intended to be used directly.

Verify that a connection can be successfully established between a node
and the sensu-backend server.  Its primary use is as a precondition to
prevent configuration changes from being applied if the sensu_backend
server cannot be reached, but it could potentially be used for other
purposes such as monitoring.

#### Examples

##### Verify API connectivity to localhost:8080

```puppet
sensu_api_validator { 'sensu':
  sensu_api_server => 'localhost',
  sensu_api_ort    => 8080,
}
```

#### Properties

The following properties are available in the `sensu_api_validator` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `sensu_api_validator` type.

* [`name`](#name)
* [`provider`](#provider)
* [`sensu_api_port`](#sensu_api_port)
* [`sensu_api_server`](#sensu_api_server)
* [`test_url`](#test_url)
* [`timeout`](#timeout)
* [`use_ssl`](#use_ssl)

##### <a name="name"></a>`name`

namevar

An arbitrary name used as the identity of the resource.

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_api_validator` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

##### <a name="sensu_api_port"></a>`sensu_api_port`

The port that the sensu_api server should be listening on.

Default value: `8080`

##### <a name="sensu_api_server"></a>`sensu_api_server`

The DNS name or IP address of the server where sensu_api should be running.

Default value: `localhost`

##### <a name="test_url"></a>`test_url`

URL to use for testing if the Sensu backend is up

Default value: `/version`

##### <a name="timeout"></a>`timeout`

The max number of seconds that the validator should wait before giving up and deciding that sensu_api is not running;
defaults to 15 seconds.

Default value: `30`

##### <a name="use_ssl"></a>`use_ssl`

Whether the connection will be attemped using https

Default value: ``false``

### <a name="sensu_asset"></a>`sensu_asset`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.

#### Examples

##### Create an asset with multiple builds

```puppet
sensu_asset { 'test':
  ensure => 'present',
  builds => [
    {
      "url" => "https://assets.bonsai.sensu.io/981307deb10ebf1f1433a80da5504c3c53d5c44f/sensu-go-cpu-check_0.0.3_linux_amd64.tar.gz",
      "sha512" => "487ab34b37da8ce76d2657b62d37b35fbbb240c3546dd463fa0c37dc58a72b786ef0ca396a0a12c8d006ac7fa21923e0e9ae63419a4d56aec41fccb574c1a5d3",
      "filters" => [
        "entity.system.os == 'linux'",
        "entity.system.arch == 'amd64'"
      ],
      "headers" => {
        "Authorization" => "Bearer $TOKEN",
        "X-Forwarded-For" => "client1, proxy1, proxy2",
      }
    },
    {
      "url" => "https://assets.bonsai.sensu.io/981307deb10ebf1f1433a80da5504c3c53d5c44f/sensu-go-cpu-check_0.0.3_linux_armv7.tar.gz",
      "sha512" => "70df8b7e9aa36cf942b972e1781af04815fa560441fcdea1d1538374066a4603fc5566737bfd6c7ffa18314edb858a9f93330a57d430deeb7fd6f75670a8c68b",
      "filters" => [
        "entity.system.os == 'linux'",
        "entity.system.arch == 'arm'",
        "entity.system.arm_version == 7"
      ],
      "headers" => {
        "Authorization" => "Bearer $TOKEN",
        "X-Forwarded-For" => "client1, proxy1, proxy2",
      }
    },
    {
      "url" => "https://assets.bonsai.sensu.io/981307deb10ebf1f1433a80da5504c3c53d5c44f/sensu-go-cpu-check_0.0.3_windows_amd64.tar.gz",
      "sha512" => "10d6411e5c8bd61349897cf8868087189e9ba59c3c206257e1ebc1300706539cf37524ac976d0ed9c8099bdddc50efadacf4f3c89b04a1a8bf5db581f19c157f",
      "filters" => [
        "entity.system.os == 'windows'",
        "entity.system.arch == 'amd64'"
      ],
      "headers" => {
        "Authorization" => "Bearer $TOKEN",
        "X-Forwarded-For" => "client1, proxy1, proxy2",
      }
    }
  ],
}
```

##### Create an asset with composite name in `dev` namespace

```puppet
sensu_asset { 'test in dev':
  ensure => 'present',
  builds => ...
}
```

#### Properties

The following properties are available in the `sensu_asset` type.

##### `annotations`

Arbitrary, non-identifying metadata to include with event data.

##### `builds`

A list of asset builds used to define multiple artifacts which provide the named asset.

Keys:
* url: required
* sha512: required
* filters: optional Array
* headers: optional Hash

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `headers`

HTTP headers to appy to asset retrieval requests.

##### `labels`

Custom attributes to include with event data, which can be queried like regular attributes.

##### `namespace`

The Sensu RBAC namespace that this asset belongs to.

Default value: `default`

#### Parameters

The following parameters are available in the `sensu_asset` type.

* [`bonsai`](#bonsai)
* [`name`](#name)
* [`provider`](#provider)
* [`resource_name`](#resource_name)

##### <a name="bonsai"></a>`bonsai`

Valid values: ``true``, ``false``

Private property used by sensu_bonsai_asset type

##### <a name="name"></a>`name`

namevar

The name of the asset.
The name supports composite names that can define the namespace.
An example composite name to define resource named `test` in namespace `dev`: `test in dev`

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_asset` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="resource_name"></a>`resource_name`

The name of the asset.

### <a name="sensu_bonsai_asset"></a>`sensu_bonsai_asset`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.

#### Examples

##### Install a bonsai asset

```puppet
sensu_bonsai_asset { 'sensu/sensu-pagerduty-handler':
  ensure  => 'present',
}
```

##### Install specific version of a bonsai asset

```puppet
sensu_bonsai_asset { 'sensu/sensu-pagerduty-handler':
  ensure  => 'present',
  version => '1.2.0',
}
```

##### Install latest version of a bonsai asset

```puppet
sensu_bonsai_asset { 'sensu/sensu-pagerduty-handler':
  ensure  => 'present',
  version => 'latest',
}
```

##### Install a bonsai asset into `dev` namespace using composite names

```puppet
sensu_bonsai_asset { 'sensu/sensu-pagerduty-handler in dev':
  ensure  => 'present',
}
```

#### Properties

The following properties are available in the `sensu_bonsai_asset` type.

##### `ensure`

Valid values: `present`, `absent`

Bonsai asset state for Sensu Go asset

Default value: `present`

##### `version`

Valid values: `latest`, `/^(v)?[0-9\.]+$/`

Specific version to install, or latest

#### Parameters

The following parameters are available in the `sensu_bonsai_asset` type.

* [`bonsai_name`](#bonsai_name)
* [`bonsai_namespace`](#bonsai_namespace)
* [`name`](#name)
* [`namespace`](#namespace)
* [`provider`](#provider)
* [`rename`](#rename)

##### <a name="bonsai_name"></a>`bonsai_name`

Bonsai asset name

##### <a name="bonsai_namespace"></a>`bonsai_namespace`

Bonsai asset namespace

##### <a name="name"></a>`name`

namevar

Bonsai asset name

##### <a name="namespace"></a>`namespace`

The Sensu RBAC namespace that this asset belongs to.

Default value: `default`

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_bonsai_asset` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="rename"></a>`rename`

Name for Sensu Go asset

### <a name="sensu_check"></a>`sensu_check`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.
* `sensu_handler` - Puppet will autorequie `sensu_handler` resources defined in `handlers` property.
* `sensu_asset` - Puppet will autorequire `sensu_asset` resources defined in `runtime_assets` property.
* `sensu_hook` - Puppet will autorequire `sensu_hook` resources defined in `check_hooks` property.

#### Examples

##### Create a check

```puppet
sensu_check { 'test':
  ensure        => 'present',
  command       => 'check-http.rb',
  subscriptions => ['demo'],
  handlers      => ['email'],
  interval      => 60,
}
```

##### Create a check that has a hook

```puppet
sensu_check { 'test':
  ensure        => 'present',
  command       => 'check-cpu.sh -w 75 -c 90',
  subscriptions => ['linux'],
  check_hooks   => [
    { 'critical' => ['ps'] },
    { 'warning'  => ['ps'] },
  ],
  interval      => 60,
}
```

##### Create a check with namespace `dev` in the name

```puppet
sensu_check { 'test in dev':
  ensure        => 'present',
  command       => 'check-http.rb',
  subscriptions => ['demo'],
  handlers      => ['email'],
  interval      => 60,
}
```

#### Properties

The following properties are available in the `sensu_check` type.

##### `annotations`

Arbitrary, non-identifying metadata to include with event data.

##### `check_hooks`

An array of check response types with respective arrays of Sensu hook names.

##### `command`

The check command to be executed.

##### `cron`

Valid values: `/.*/`, `absent`

When the check should be executed, using the Cron syntax.

##### `discard_output`

Valid values: ``true``, ``false``

Discard check output after extracting metrics.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `env_vars`

Valid values: `/.*/`, `absent`

An array of environment variables to use with command execution.

##### `handlers`

An array of Sensu event handlers (names) to use for events created by the check.

##### `high_flap_threshold`

Valid values: `/^[0-9]+$/`, `absent`

The flap detection high threshold (% state change) for the check

##### `interval`

Valid values: `/^[0-9]+$/`, `absent`

The frequency in seconds the check is executed.

##### `labels`

Custom attributes to include with event data, which can be queried like regular attributes.

##### `low_flap_threshold`

Valid values: `/^[0-9]+$/`, `absent`

The flap detection low threshold (% state change) for the check

##### `max_output_size`

Maximum size, in bytes, of stored check outputs.

##### `namespace`

The Sensu RBAC namespace that this check belongs to.

Default value: `default`

##### `output_metric_format`

Valid values: `nagios_perfdata`, `graphite_plaintext`, `influxdb_line`, `opentsdb_line`, `prometheus_text`, `absent`

The metric format generated by the check command.

##### `output_metric_handlers`

Valid values: `/.*/`, `absent`

An array of Sensu handlers to use for events created by the check.

##### `output_metric_tags`

Custom tags you can apply to enrich metric points produced by check output metric extraction."
Consists of Array of Hashes, each Hash must contain `name` and `value` keys.

##### `proxy_entity_name`

Valid values: `/^[\w\.\-]+$/`, `absent`

The entity name, used to create a proxy entity for an external resource (i.e., a network switch).

##### `proxy_requests`

Proxy requests attributes

Valid keys:
* entity_attributes - Optional Array
* splay - Optional Boolean (default: false)
* splay_coverage - Optional Integer (default: 0)

##### `publish`

Valid values: ``true``, ``false``

If check requests are published for the check.

Default value: `true`

##### `round_robin`

Valid values: ``true``, ``false``

If the check should be executed on a single entity within a subscription in a round-robin fashion.

##### `runtime_assets`

Valid values: `/.*/`, `absent`

An array of Sensu assets (names), required at runtime for the execution of the command

##### `secrets`

Array of the name/secret pairs to use with command execution.
Example: [{'name' => 'ANSIBLE_HOST', 'secret' => 'sensu-ansible-host' }]

##### `silenced`

Valid values: ``true``, ``false``

If the event is to be silenced.

##### `stdin`

Valid values: ``true``, ``false``

If the Sensu agent writes JSON serialized Sensu entity and check data to the command process' STDIN

Default value: `false`

##### `subscriptions`

An array of Sensu entity subscriptions that check requests will be sent to.

##### `timeout`

Valid values: `/^[0-9]+$/`, `absent`

The check execution duration timeout in seconds (hard stop).

##### `ttl`

Valid values: `/^[0-9]+$/`, `absent`

The time to live (TTL) in seconds until check results are considered stale.

#### Parameters

The following parameters are available in the `sensu_check` type.

* [`name`](#name)
* [`provider`](#provider)
* [`resource_name`](#resource_name)

##### <a name="name"></a>`name`

namevar

The name of the check.
The name supports composite names that can define the namespace.
An example composite name to define resource named `test` in namespace `dev`: `test in dev`

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_check` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="resource_name"></a>`resource_name`

The name of the check.

### <a name="sensu_cluster_federation"></a>`sensu_cluster_federation`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`

#### Examples

##### Create a federated cluster

```puppet
sensu_cluster_federation { 'us-west-2a':
  ensure    => 'present',
  api_urls  => ['http://10.0.0.1:8080','http://10.0.0.2:8080','http://10.0.0.3:8080'],
}
```

#### Properties

The following properties are available in the `sensu_cluster_federation` type.

##### `api_urls`

Federated cluster backend API URLs

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `sensu_cluster_federation` type.

* [`name`](#name)
* [`provider`](#provider)

##### <a name="name"></a>`name`

namevar

The name of the federated cluster

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_cluster_federation` resource. You will seldom need to specify this ---
Puppet will usually discover the appropriate provider for your platform.

### <a name="sensu_cluster_federation_member"></a>`sensu_cluster_federation_member`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`

#### Examples

##### Add to a federated cluster

```puppet
sensu_cluster_federation_member { 'http://10.0.0.1:8080':
  ensure   => 'present',
  cluster  => 'us-west-2a',
}
```

##### Add to a federated cluster to `us-west-2a` cluster using composite name

```puppet
sensu_cluster_federation_member { 'http://10.0.0.1:8080 in us-west-2a':
  ensure => 'present',
}
```

#### Properties

The following properties are available in the `sensu_cluster_federation_member` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `sensu_cluster_federation_member` type.

* [`api_url`](#api_url)
* [`cluster`](#cluster)
* [`name`](#name)
* [`provider`](#provider)

##### <a name="api_url"></a>`api_url`

API URL to add to the federated cluster, defaults to name

##### <a name="cluster"></a>`cluster`

Federated cluster name

##### <a name="name"></a>`name`

namevar

The name of the resource

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_cluster_federation_member` resource. You will seldom need to specify this
--- Puppet will usually discover the appropriate provider for your platform.

### <a name="sensu_cluster_member"></a>`sensu_cluster_member`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`

#### Examples

##### Add a cluster member

```puppet
sensu_cluster_member { 'backend2':
  ensure    => 'present',
  peer_urls => ['http://192.168.52.12:2380'],
}
```

#### Properties

The following properties are available in the `sensu_cluster_member` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `peer_urls`

Array of cluster peer URLs

#### Parameters

The following parameters are available in the `sensu_cluster_member` type.

* [`id`](#id)
* [`name`](#name)
* [`provider`](#provider)

##### <a name="id"></a>`id`

Cluster member ID - read-only

##### <a name="name"></a>`name`

namevar

The name of the cluster member.

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_cluster_member` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

### <a name="sensu_cluster_role"></a>`sensu_cluster_role`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`

#### Examples

##### Add a cluster role

```puppet
sensu_cluster_role { 'test':
  ensure => 'present',
  rules  => [{'verbs' => ['get','list'], 'resources' => ['checks'], 'resource_names' => ['']}],
}
```

#### Properties

The following properties are available in the `sensu_cluster_role` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `rules`

The rulesets that a role applies.

#### Parameters

The following parameters are available in the `sensu_cluster_role` type.

* [`name`](#name)
* [`provider`](#provider)

##### <a name="name"></a>`name`

namevar

The name of the role.

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_cluster_role` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="sensu_cluster_role_binding"></a>`sensu_cluster_role_binding`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`
* `sensu_cluster_role` - Puppet will autorequire `sensu_cluster_role` resource defined in `role_ref` property.
* `sensu_user` - Puppet will autorequire `sensu_user` resources based on users and groups defined for the `subjects` property.

#### Examples

##### Add a cluster role binding

```puppet
sensu_cluster_role_binding { 'test':
  ensure   => 'present',
  role_ref => {'type' => 'ClusterRole', 'name' => 'test-role'},
  subjects => [
    { 'type' => 'User', 'name' => 'test-user' }
  ],
}
```

##### Add a cluster role binding for a Role

```puppet
sensu_cluster_role_binding { 'test':
  ensure   => 'present',
  role_ref => {'type' => 'Role', 'name' => 'test-role'},
  subjects => [
    { 'type' => 'User', 'name' => 'test-user' }
  ],
}
```

#### Properties

The following properties are available in the `sensu_cluster_role_binding` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `role_ref`

References a role in the current namespace or a cluster role.

##### `subjects`

The users or groups being assigned.

#### Parameters

The following parameters are available in the `sensu_cluster_role_binding` type.

* [`name`](#name)
* [`provider`](#provider)

##### <a name="name"></a>`name`

namevar

The name of the role binding.

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_cluster_role_binding` resource. You will seldom need to specify this ---
Puppet will usually discover the appropriate provider for your platform.

### <a name="sensu_command"></a>`sensu_command`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`

#### Examples

##### Add sensuctl command from Bonsai asset

```puppet
sensu_command { 'command-test':
  ensure      => 'present',
  bonsai_name => 'sensu/command-test',
}
```

##### Add command from specific version of a Bonsai asset

```puppet
sensu_command { 'command-test':
  ensure         => 'present',
  bonsai_name    => 'sensu/command-test',
  bonsai_version => '0.4.0',
}
```

##### Add command from URL

```puppet
sensu_command { 'command-test':
  ensure => 'present',
  url    => 'https://github.com/amdprophet/command-test/releases/download/v0.0.4/command-test_0.0.4_linux_amd64.tar.gz',
  sha512 => '67aeba3652def271b1921bc1b4621354ad254c89946ebc8d1e39327f69a902d91f4b0326c9020a4a03e4cfbb718b454b6180f9c39aaff1e60daf6310be66244f'
}
```

#### Properties

The following properties are available in the `sensu_command` type.

##### `bonsai_version`

Valid values: `latest`, `/[0-9\.]+/`

Specific Bonsai asset version to install, or latest

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `sha512`

The checksum of the asset

##### `url`

The URL location of the asset.

#### Parameters

The following parameters are available in the `sensu_command` type.

* [`bonsai_name`](#bonsai_name)
* [`name`](#name)
* [`provider`](#provider)

##### <a name="bonsai_name"></a>`bonsai_name`

Bonsai asset name

##### <a name="name"></a>`name`

namevar

command name

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_command` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="sensu_entity"></a>`sensu_entity`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.
* `sensu_handler` - Puppet will autorequie `sensu_handler` resource defined in `deregistration.handler` property.

#### Examples

##### Create an entity

```puppet
sensu_entity { 'test':
  ensure       => 'present',
  entity_class => 'proxy',
}
```

##### Create an entity with namespace `dev` in the name

```puppet
sensu_entity { 'test in dev':
  ensure       => 'present',
  entity_class => 'proxy',
}
```

#### Properties

The following properties are available in the `sensu_entity` type.

##### `annotations`

Arbitrary, non-identifying metadata to include with event data.

##### `deregister`

Valid values: ``true``, ``false``

If the entity should be removed when it stops sending keepalive messages.

Default value: `false`

##### `deregistration`

A map containing a handler name, for use when an entity is deregistered.

Valid keys:
* handler - Opional - The name of the handler to be called when an entity is deregistered.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `entity_class`

The entity type

##### `labels`

Custom attributes to include with event data, which can be queried like regular attributes.

##### `last_seen`

Timestamp the entity was last seen, in epoch time.

##### `namespace`

The Sensu RBAC namespace that this entity belongs to.

Default value: `default`

##### `redact`

List of items to redact from log messages.

##### `subscriptions`

A list of subscription names for the entity

##### `system`

System information about the entity, such as operating system and platform.

#### Parameters

The following parameters are available in the `sensu_entity` type.

* [`name`](#name)
* [`provider`](#provider)
* [`resource_name`](#resource_name)

##### <a name="name"></a>`name`

namevar

The name of the entity.
The name supports composite names that can define the namespace.
An example composite name to define resource named `test` in namespace `dev`: `test in dev`

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_entity` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="resource_name"></a>`resource_name`

The name of the entity.

### <a name="sensu_etcd_replicator"></a>`sensu_etcd_replicator`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`

#### Examples

##### Create an Etcd Replicator

```puppet
sensu_etcd_replicator { 'role_replicator':
  ensure                       => 'present',
  ca_cert                      => '/path/to/ssl/trusted-certificate-authorities.pem',
  cert                         => '/path/to/ssl/cert.pem',
  key                          => '/path/to/ssl/key.pem',
  insecure                     => false,
  url                          => 'http://127.0.0.1:2379',
  api_version                  => 'core/v2',
  resource_name                => 'Role',
  replication_interval_seconds => 30,
}
```

#### Properties

The following properties are available in the `sensu_etcd_replicator` type.

##### `api_version`

Sensu API version of the resource to replicate

Default value: `core/v2`

##### `ca_cert`

Path to an the PEM-format CA certificate to use for TLS client authentication.

##### `cert`

Path to the PEM-format certificate to use for TLS client authentication.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `insecure`

Valid values: ``true``, ``false``

true to disable transport security.

Default value: `false`

##### `key`

Path to the PEM-format key file associated with the cert to use for TLS client authentication.

##### `namespace`

Namespace to constrain replication to. If you do not include namespace, all namespaces for a given resource are replicated.

##### `replication_interval_seconds`

Valid values: `/^[0-9]+$/`, `absent`

The interval at which the resource will be replicated

Default value: `30`

##### `resource_name`

Name of the resource to replicate

##### `url`

Destination cluster URL. If specifying more than one, use a comma to separate.

#### Parameters

The following parameters are available in the `sensu_etcd_replicator` type.

* [`name`](#name)
* [`provider`](#provider)

##### <a name="name"></a>`name`

namevar

The name of the Etcd Replicator.

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_etcd_replicator` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

### <a name="sensu_filter"></a>`sensu_filter`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.
* `sensu_asset` - Puppet will autorequire `sensu_asset` resources defined in `runtime_assets` property.

#### Examples

##### Create a filter

```puppet
sensu_filter { 'test':
  ensure      => 'present',
  action      => 'allow',
  expressions => ["event.entity.labels.environment == 'production'"],
}
```

##### Create a filter with namespace `dev` in the name

```puppet
sensu_filter { 'test in dev':
  ensure      => 'present',
  action      => 'allow',
  expressions => ["event.entity.labels.environment == 'production'"],
}
```

#### Properties

The following properties are available in the `sensu_filter` type.

##### `action`

Valid values: `allow`, `deny`

Action to take with the event if the filter expressions match.

##### `annotations`

Arbitrary, non-identifying metadata to include with event data.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `expressions`

Filter expressions to be compared with event data.

##### `labels`

Custom attributes to include with event data, which can be queried like regular attributes.

##### `namespace`

The Sensu RBAC namespace that this filter belongs to.

Default value: `default`

##### `runtime_assets`

Valid values: `/.*/`, `absent`

Assets to be applied to the filter's execution context.

#### Parameters

The following parameters are available in the `sensu_filter` type.

* [`name`](#name)
* [`provider`](#provider)
* [`resource_name`](#resource_name)

##### <a name="name"></a>`name`

namevar

The name of the filter.
The name supports composite names that can define the namespace.
An example composite name to define resource named `test` in namespace `dev`: `test in dev`

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_filter` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="resource_name"></a>`resource_name`

The name of the filter.

### <a name="sensu_handler"></a>`sensu_handler`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.
* `sensu_filter` - Puppet will autorequire `sensu_filter` resources defined in `filters` property.
* `sensu_mutator` - Puppet will autorequire `sensu_mutator` resource defined for `mutator` property.
* `sensu_handler` - Puppet will autorequire `sensu_handler` resources defined for `handlers` property.
* `sensu_asset` - Puppet will autorequire `sensu_asset` resources defined in `runtime_assets` property.

#### Examples

##### Create a handler

```puppet
sensu_handler { 'test':
  ensure  => 'present',
  type    => 'pipe',
  command => 'notify.rb'
}
```

##### Create a handler with namespace `dev` in the name

```puppet
sensu_handler { 'test in dev':
  ensure  => 'present',
  type    => 'pipe',
  command => 'notify.rb'
}
```

#### Properties

The following properties are available in the `sensu_handler` type.

##### `annotations`

Arbitrary, non-identifying metadata to include with event data.

##### `command`

Valid values: `/.*/`, `absent`

The handler command to be executed.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `env_vars`

Valid values: `/.*/`, `absent`

An array of environment variables to use with command execution.

##### `filters`

Valid values: `/.*/`, `absent`

An array of Sensu event filters (names) to use when filtering events for the handler.

##### `handlers`

Valid values: `/.*/`, `absent`

An array of Sensu event handlers (names) to use for events using the handler set.

##### `labels`

Custom attributes to include with event data, which can be queried like regular attributes.

##### `mutator`

Valid values: `/.*/`, `absent`

The Sensu event mutator (name) to use to mutate event data for the handler.

##### `namespace`

The Sensu RBAC namespace that this handler belongs to.

Default value: `default`

##### `runtime_assets`

Valid values: `/.*/`, `absent`

An array of Sensu assets (names), required at runtime for the execution of the command

##### `secrets`

Array of the name/secret pairs to use with command execution.
Example: [{'name' => 'ANSIBLE_HOST', 'secret' => 'sensu-ansible-host' }]

##### `socket`

The socket definition scope, used to configure the TCP/UDP handler socket.

Valid keys:
* host - Required - The socket host address (IP or hostname) to connect to.
* port - Required - The socket port to connect to.

##### `timeout`

Valid values: `/^[0-9]+$/`, `absent`

The handler execution duration timeout in seconds (hard stop)

##### `type`

Valid values: `pipe`, `tcp`, `udp`, `set`

The handler type.

#### Parameters

The following parameters are available in the `sensu_handler` type.

* [`name`](#name)
* [`provider`](#provider)
* [`resource_name`](#resource_name)

##### <a name="name"></a>`name`

namevar

The name of the handler.
The name supports composite names that can define the namespace.
An example composite name to define resource named `test` in namespace `dev`: `test in dev`

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_handler` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="resource_name"></a>`resource_name`

The name of the handler.

### <a name="sensu_hook"></a>`sensu_hook`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.
* `sensu_asset` - Puppet will autorequire `sensu_asset` resources defined in `runtime_assets` property.

#### Examples

##### Create a hook

```puppet
sensu_hook { 'test':
  ensure  => 'present',
  command => 'ps aux',
}
```

##### Create a hook with namespace `dev` in the name

```puppet
sensu_hook { 'test in dev':
  ensure  => 'present',
  command => 'ps aux',
}
```

#### Properties

The following properties are available in the `sensu_hook` type.

##### `annotations`

Arbitrary, non-identifying metadata to include with event data.

##### `command`

The hook command to be executed.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `labels`

Custom attributes to include with event data, which can be queried like regular attributes.

##### `namespace`

The Sensu RBAC namespace that this hook belongs to.

Default value: `default`

##### `runtime_assets`

Valid values: `/.*/`, `absent`

An array of Sensu assets (names), required at runtime for the execution of the command

##### `stdin`

Valid values: ``true``, ``false``

If the Sensu agent writes JSON serialized Sensu entity and check data to the command process' STDIN.

Default value: `false`

##### `timeout`

The hook execution duration timeout in seconds (hard stop)

Default value: `60`

#### Parameters

The following parameters are available in the `sensu_hook` type.

* [`name`](#name)
* [`provider`](#provider)
* [`resource_name`](#resource_name)

##### <a name="name"></a>`name`

namevar

The name of the hook.
The name supports composite names that can define the namespace.
An example composite name to define resource named `test` in namespace `dev`: `test in dev`

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_hook` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

##### <a name="resource_name"></a>`resource_name`

The name of the hook.

### <a name="sensu_ldap_auth"></a>`sensu_ldap_auth`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`

#### Examples

##### Add a LDAP auth

```puppet
sensu_ldap_auth { 'openldap':
  ensure              => 'present',
  servers             => [
    {
      'host' => '127.0.0.1',
      'port' => 389,
      'binding' => {
        'user_dn' => 'cn=binder,dc=acme,dc=org',
        'password' => 'P@ssw0rd!'
      },
      'group_search' => {
        'base_dn' => 'dc=acme,dc=org',
      },
      'user_search'  => {
        'base_dn' => 'dc=acme,dc=org',
      },
    },
  ],
}
```

##### Add an LDAP auth that uses memberOf attribute by omitting group_search

```puppet
sensu_ldap_auth { 'openldap':
  ensure              => 'present',
  servers             => [
    {
      'host' => '127.0.0.1',
      'port' => 389,
      'binding' => {
        'user_dn' => 'cn=binder,dc=acme,dc=org',
        'password' => 'P@ssw0rd!'
      },
      'user_search'  => {
        'base_dn' => 'dc=acme,dc=org',
      },
    },
  ],
}
```

#### Properties

The following properties are available in the `sensu_ldap_auth` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `groups_prefix`

The prefix added to all LDAP groups.

##### `servers`

LDAP servers as Array of Hashes

Keys:
* host: required
* port: required
* group_search: optional (omit to use memberOf)
* user_search: required
* binding: optional Hash
* insecure: default is `false`
* security: default is `tls`
* trusted_ca_file: default is `""`
* client_cert_file: default is `""`
* client_key_file: default is `""`
* default_upn_domain: default is `""`

group_search keys:
* base_dn: required
* attribute: default is `member`
* name_attribute: default is `cn`
* object_class: default is `groupOfNames`

user_search Keys:
* base_dn: required
* attribute: default is `uid`
* name_attribute: default is `cn`
* object_class: default is `person`

binding keys:
* user_dn: required
* password: required

##### `username_prefix`

The prefix added to all LDAP usernames.

#### Parameters

The following parameters are available in the `sensu_ldap_auth` type.

* [`name`](#name)
* [`provider`](#provider)

##### <a name="name"></a>`name`

namevar

The name of the LDAP auth.

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_ldap_auth` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="sensu_license"></a>`sensu_license`

**NOTE** This is a private type not intended to be used directly.

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`
* `file` - Puppet will autorequire `file` resources defined in `file` property.

#### Properties

The following properties are available in the `sensu_license` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `sensu_license` type.

* [`file`](#file)
* [`name`](#name)
* [`provider`](#provider)

##### <a name="file"></a>`file`

Path to license file

##### <a name="name"></a>`name`

namevar

The name of the resource.

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_license` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="sensu_mutator"></a>`sensu_mutator`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.
* `sensu_asset` - Puppet will autorequire `sensu_asset` resources defined in `runtime_assets` property.

#### Examples

##### Create a mutator

```puppet
sensu_mutator { 'example':
  ensure  => 'present',
  command => 'example-mutator.rb',
}
```

##### Create a mutator with namespace `dev` in the name

```puppet
sensu_mutator { 'example in dev':
  ensure  => 'present',
  command => 'example-mutator.rb',
}
```

#### Properties

The following properties are available in the `sensu_mutator` type.

##### `annotations`

Arbitrary, non-identifying metadata to include with event data.

##### `command`

The mutator command to be executed.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `env_vars`

Valid values: `/.*/`, `absent`

An array of environment variables to use with command execution.

##### `labels`

Custom attributes to include with event data, which can be queried like regular attributes.

##### `namespace`

The Sensu RBAC namespace that this mutator belongs to.

Default value: `default`

##### `runtime_assets`

Valid values: `/.*/`, `absent`

An array of Sensu assets (names), required at runtime for the execution of the command

##### `secrets`

Array of the name/secret pairs to use with command execution.
Example: [{'name' => 'ANSIBLE_HOST', 'secret' => 'sensu-ansible-host' }]

##### `timeout`

Valid values: `/^[0-9]+$/`, `absent`

The mutator execution duration timeout in seconds (hard stop)

#### Parameters

The following parameters are available in the `sensu_mutator` type.

* [`name`](#name)
* [`provider`](#provider)
* [`resource_name`](#resource_name)

##### <a name="name"></a>`name`

namevar

The name of the mutator.
The name supports composite names that can define the namespace.
An example composite name to define resource named `test` in namespace `dev`: `test in dev`

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_mutator` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="resource_name"></a>`resource_name`

The name of the mutator.

### <a name="sensu_namespace"></a>`sensu_namespace`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`

#### Examples

##### Add an namespace

```puppet
sensu_namespace { 'test':
  ensure => 'present',
}
```

#### Properties

The following properties are available in the `sensu_namespace` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `sensu_namespace` type.

* [`name`](#name)
* [`provider`](#provider)

##### <a name="name"></a>`name`

namevar

The name of the namespace.

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_namespace` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="sensu_oidc_auth"></a>`sensu_oidc_auth`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`

#### Examples

##### Add an Active Directory auth

```puppet
sensu_oidc_auth { 'oidc':
  ensure            => 'present',
  additional_scopes => ['email','groups'],
  client_id         => '0oa13ry4ypeDDBpxF357',
  client_secret     => 'DlArQRfND4BKBUyO0mE-TL2PWOVwyGjIO1fdk9gX',
  groups_claim      => 'groups',
  groups_prefix     => 'oidc:',
  redirect_uri      => 'https://sensu-backend.example.com:8080/api/enterprise/authentication/v2/oidc/callback',
  server            => 'https://idp.example.com',
  username_claim    => 'email',
  username_prefix   => 'oidc:'
}
```

#### Properties

The following properties are available in the `sensu_oidc_auth` type.

##### `additional_scopes`

Scopes to include in the claims

##### `client_id`

The OIDC provider application "Client ID"

##### `client_secret`

The OIDC provider application "Client Secret"

##### `disable_offline_access`

Valid values: ``true``, ``false``

Sets if OIDC provider can include the offline_access scope

Default value: `false`

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `groups_claim`

The claim to use to form the associated RBAC groups.

##### `groups_prefix`

A prefix to use to form the final RBAC groups if required.

##### `redirect_uri`

Redirect URL to provide to the OIDC provider.

##### `server`

The location of the OIDC server you wish to authenticate against.

##### `username_claim`

The claim to use to form the final RBAC user name.

##### `username_prefix`

A prefix to use to form the final RBAC user name.

#### Parameters

The following parameters are available in the `sensu_oidc_auth` type.

* [`name`](#name)
* [`provider`](#provider)

##### <a name="name"></a>`name`

namevar

The name of the AD auth.

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_oidc_auth` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="sensu_plugin"></a>`sensu_plugin`

**Autorequires**:
* `Package[sensu-plugins-ruby]`

#### Examples

##### Install a sensu plugin

```puppet
sensu_plugin { 'disk-checks':
  ensure  => 'present',
}
```

##### Install specific version of a sensu plugin

```puppet
sensu_plugin { 'disk-checks':
  ensure  => 'present',
  version => '4.0.0',
}
```

##### Install latest version of a sensu plugin

```puppet
sensu_plugin { 'disk-checks':
  ensure  => 'present',
  version => 'latest',
}
```

#### Properties

The following properties are available in the `sensu_plugin` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `version`

Valid values: `latest`, `/[0-9\.]+/`

Specific version to install, or latest

#### Parameters

The following parameters are available in the `sensu_plugin` type.

* [`clean`](#clean)
* [`extension`](#extension)
* [`name`](#name)
* [`provider`](#provider)
* [`proxy`](#proxy)
* [`source`](#source)

##### <a name="clean"></a>`clean`

Valid values: ``true``, ``false``

Clean up (remove) other installed versions of the plugin(s) and/or extension(s)

Default value: ``true``

##### <a name="extension"></a>`extension`

Valid values: ``true``, ``false``

Sets to install an extension instead of a plugin

Default value: ``false``

##### <a name="name"></a>`name`

namevar

Plugin or extension name

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_plugin` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="proxy"></a>`proxy`

Install Sensu plugins and extensions via a PROXY URL

##### <a name="source"></a>`source`

Install Sensu plugins and extensions from a custom SOURCE

### <a name="sensu_postgres_config"></a>`sensu_postgres_config`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`

#### Examples

##### Create an PostgreSQL datastore

```puppet
sensu_postgres_config { 'puppet':
  ensure    => 'present',
  dsn       => 'postgresql://sensu:changeme@localhost:5432/sensu',
  pool_size => 20,
}
```

#### Properties

The following properties are available in the `sensu_postgres_config` type.

##### `batch_buffer`

Valid values: `/^[0-9]+$/`

Maximum number of requests to buffer in memory.

Default value: `0`

##### `batch_size`

Valid values: `/^[0-9]+$/`

Number of requests in each PostgreSQL write transaction

Default value: `1`

##### `batch_workers`

Valid values: `/^[0-9]+$/`

Number of requests in each PostgreSQL write transaction, defaults to value for pool_size

##### `dsn`

Use the dsn attribute to specify the data source names as a URL or PostgreSQL connection string

##### `enable_round_robin`

Valid values: ``true``, ``false``

If true, enables round robin scheduling on PostgreSQL

Default value: `false`

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `pool_size`

Valid values: `/^[0-9]+$/`

The maximum number of connections to hold in the PostgreSQL connection pool

Default value: `0`

##### `strict`

Valid values: ``true``, ``false``

Perform configuration validation when configuring this resource

Default value: `false`

#### Parameters

The following parameters are available in the `sensu_postgres_config` type.

* [`name`](#name)
* [`provider`](#provider)

##### <a name="name"></a>`name`

namevar

The name of the postgres config

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_postgres_config` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

### <a name="sensu_resources"></a>`sensu_resources`

Metatype for sensu resources

#### Examples

##### Purge unmanaged sensu_check resources

```puppet
sensu_resources { 'sensu_check':
  purge => true,
}
```

#### Parameters

The following parameters are available in the `sensu_resources` type.

* [`agent_entity_configs`](#agent_entity_configs)
* [`name`](#name)
* [`purge`](#purge)

##### <a name="agent_entity_configs"></a>`agent_entity_configs`

Types of configs to purge for sensu_agent_entity_configs, eg ['subscriptions','labels']

##### <a name="name"></a>`name`

namevar

The name of the type to be managed.

##### <a name="purge"></a>`purge`

Valid values: ``true``, ``false``, `yes`, `no`

Whether to purge unmanaged sensu resources.  When set to `true`, this will
delete any resource that is not specified in your configuration and is not
autorequired by any managed resources.

Default value: ``false``

### <a name="sensu_role"></a>`sensu_role`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.

#### Examples

##### Add a role

```puppet
sensu_role { 'test':
  ensure => 'present',
  rules  => [{'verbs' => ['get','list'], 'resources' => ['checks'], 'resource_names' => ['']}],
}
```

##### Add a role with namespace `dev` in the name

```puppet
sensu_role { 'test in dev':
  ensure => 'present',
  rules  => [{'verbs' => ['get','list'], 'resources' => ['checks'], 'resource_names' => ['']}],
}
```

#### Properties

The following properties are available in the `sensu_role` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `namespace`

Namespace the role is restricted to.

Default value: `default`

##### `rules`

The rulesets that a role applies.

#### Parameters

The following parameters are available in the `sensu_role` type.

* [`name`](#name)
* [`provider`](#provider)
* [`resource_name`](#resource_name)

##### <a name="name"></a>`name`

namevar

The name of the role.
The name supports composite names that can define the namespace.
An example composite name to define resource named `test` in namespace `dev`: `test in dev`

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_role` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

##### <a name="resource_name"></a>`resource_name`

The name of the role.

### <a name="sensu_role_binding"></a>`sensu_role_binding`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`
* `sensu_role` - Puppet will autorequire `sensu_role` resource defined in `role_ref` property.
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.
* `sensu_user` - Puppet will autorequire `sensu_user` resources based on users and groups defined for the `subjects` property.

#### Examples

##### Add a role binding

```puppet
sensu_role_binding { 'test':
  ensure   => 'present',
  role_ref => {'type' => 'Role', 'name' => 'test-role'},
  subjects => [
    { 'type' => 'User', 'name' => 'test-user' }
  ],
}
```

##### Add a role binding for a ClusterRole

```puppet
sensu_role_binding { 'test':
  ensure   => 'present',
  role_ref => {'type' => 'ClusterRole', 'name' => 'test-role'},
  subjects => [
    { 'type' => 'User', 'name' => 'test-user' }
  ],
}
```

##### Add a role binding with namespace `dev` in the name

```puppet
sensu_role_binding { 'test in dev':
  ensure   => 'present',
  role_ref => {'type' => 'Role', 'name' => 'test-role'},
  subjects => [
    { 'type' => 'User', 'name' => 'test-user' }
  ],
}
```

#### Properties

The following properties are available in the `sensu_role_binding` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `namespace`

Namespace the role binding is restricted to.

Default value: `default`

##### `role_ref`

References a role in the current namespace or a cluster role.

##### `subjects`

The users or groups being assigned.

#### Parameters

The following parameters are available in the `sensu_role_binding` type.

* [`name`](#name)
* [`provider`](#provider)
* [`resource_name`](#resource_name)

##### <a name="name"></a>`name`

namevar

The name of the binding.
The name supports composite names that can define the namespace.
An example composite name to define resource named `test` in namespace `dev`: `test in dev`

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_role_binding` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="resource_name"></a>`resource_name`

The name of the role binding.

### <a name="sensu_secret"></a>`sensu_secret`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.

#### Examples

##### Manage a secret in the default namespace

```puppet
sensu_secret { 'sensu-ansible-token in default':
  ensure           => 'present',
  id               => 'ANSIBLE_TOKEN',
  secrets_provider => 'env',
}
```

#### Properties

The following properties are available in the `sensu_secret` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `id`

The identifying key for the provider to retrieve the secret.

##### `namespace`

The Sensu RBAC namespace that this secret belongs to.

Default value: `default`

##### `secrets_provider`

The name of the Sensu provider with the secret.

#### Parameters

The following parameters are available in the `sensu_secret` type.

* [`name`](#name)
* [`provider`](#provider)
* [`resource_name`](#resource_name)

##### <a name="name"></a>`name`

namevar

The name of the secret.
The name supports composite names that can define the namespace.
An example composite name to define resource named `test` in namespace `dev`: `test in dev`

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_secret` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="resource_name"></a>`resource_name`

The name of the secret.

### <a name="sensu_secrets_vault_provider"></a>`sensu_secrets_vault_provider`

**NOTE** Property names map to the `client` hash in Sensu Go reference for a secrets VaultProvider

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`

#### Examples

##### Manage a secrets vault provider

```puppet
sensu_secrets_vault_provider { 'my_vault-api':
  ensure       => 'present',
  address      => "https://vaultserver.example.com:8200",
  token        => "VAULT_TOKEN",
  version      => "v1",
  max_retries  => 2,
  timeout      => "20s",
  tls          => {
    "ca_cert" => "/etc/ssl/certs/ca-bundle.crt"
  },
  rate_limiter => {
    "limit" => 10,
    "burst" => 100
  },
}
```

#### Properties

The following properties are available in the `sensu_secrets_vault_provider` type.

##### `address`

Vault server address.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `max_retries`

Number of times to retry connecting to the vault provider.

Default value: `2`

##### `rate_limiter`

Keys:
* limit - Maximum number of secrets requests per second that can be transmitted to the backend with the secrets API.
* burst - Maximum amount of burst allowed in a rate interval for the secrets API.

Default value: `absent`

##### `timeout`

Provider connection timeout (hard stop).

Default value: `60s`

##### `tls`

TLS object. Vault only works with TLS configured.

Default value: `absent`

##### `token`

Vault token to use for authentication.

##### `version`

HashiCorp Vault HTTP API version

#### Parameters

The following parameters are available in the `sensu_secrets_vault_provider` type.

* [`name`](#name)
* [`provider`](#provider)
* [`token_file`](#token_file)

##### <a name="name"></a>`name`

namevar

The name of the secrets provider.

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_secrets_vault_provider` resource. You will seldom need to specify this ---
Puppet will usually discover the appropriate provider for your platform.

##### <a name="token_file"></a>`token_file`

Path to file that contains token to use for authentication.

To update this resource with new content for the file, requires sending notify event from the file resource.

Example:

file { '/etc/sensu/provider-secret':
  ...
  notify => Sensu_secrets_vault_provider['my-vault'],
}

### <a name="sensu_tessen"></a>`sensu_tessen`

**NOTE** This is a private type not intended to be used directly.

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`

#### Properties

The following properties are available in the `sensu_tessen` type.

##### `ensure`

Valid values: `present`, `absent`

State of tessen

#### Parameters

The following parameters are available in the `sensu_tessen` type.

* [`name`](#name)
* [`provider`](#provider)

##### <a name="name"></a>`name`

namevar

Resource name

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_tessen` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="sensu_user"></a>`sensu_user`

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensuctl_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`

#### Examples

##### Create a user

```puppet
sensu_user { 'test':
  ensure   => 'present',
  password => 'supersecret',
  groups   => ['users'],
}
```

##### Change a user's password

```puppet
sensu_user { 'test'
  ensure   => 'present',
  password => 'newpassword',
  groups   => ['users'],
}
```

#### Properties

The following properties are available in the `sensu_user` type.

##### `disabled`

Valid values: ``true``, ``false``

The state of the user's account.

Default value: `false`

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `groups`

Groups to which the user belongs.

##### `password`

The user's password.

#### Parameters

The following parameters are available in the `sensu_user` type.

* [`configure`](#configure)
* [`configure_trusted_ca_file`](#configure_trusted_ca_file)
* [`configure_url`](#configure_url)
* [`name`](#name)
* [`provider`](#provider)

##### <a name="configure"></a>`configure`

Valid values: ``true``, ``false``

Run sensuctl configure for this user

Default value: ``false``

##### <a name="configure_trusted_ca_file"></a>`configure_trusted_ca_file`

Path to trusted CA to use with 'sensuctl configure'

Default value: `/etc/sensu/ssl/ca.crt`

##### <a name="configure_url"></a>`configure_url`

URL to use with 'sensuctl configure'

Default value: `http://127.0.0.1:8080`

##### <a name="name"></a>`name`

namevar

The name of the user.

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensu_user` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

### <a name="sensuctl_config"></a>`sensuctl_config`

**NOTE** This is a private type not intended to be used directly.

#### Parameters

The following parameters are available in the `sensuctl_config` type.

* [`chunk_size`](#chunk_size)
* [`name`](#name)
* [`path`](#path)
* [`validate_namespaces`](#validate_namespaces)

##### <a name="chunk_size"></a>`chunk_size`

sensuctl chunk-size

##### <a name="name"></a>`name`

namevar

The name of the resource.

##### <a name="path"></a>`path`

path to sensuctl

##### <a name="validate_namespaces"></a>`validate_namespaces`

Valid values: ``true``, ``false``

Determines of namespaces should be validated with sensuctl

Default value: ``true``

### <a name="sensuctl_configure"></a>`sensuctl_configure`

**NOTE** This is a private type not intended to be used directly.

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_api_validator[sensu]`
* `Sensu_user[admin]`
* `file` - Puppet will autorequire `file` resources defined in `trusted_ca_file` property.

#### Properties

The following properties are available in the `sensuctl_configure` type.

##### `config_format`

Valid values: `tabular`, `json`, `wrapped-json`, `yaml`

Set configured format for sensuctl

##### `config_namespace`

Set configured namespace for sensuctl

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `trusted_ca_file`

Path to trusted CA

Default value: `/etc/sensu/ssl/ca.crt`

##### `url`

sensu-backend URL

#### Parameters

The following parameters are available in the `sensuctl_configure` type.

* [`name`](#name)
* [`password`](#password)
* [`provider`](#provider)
* [`username`](#username)

##### <a name="name"></a>`name`

namevar

The name of the resource.

##### <a name="password"></a>`password`

Password to use with sensuctl configure

##### <a name="provider"></a>`provider`

The specific backend to use for this `sensuctl_configure` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="username"></a>`username`

Username to use with sensuctl configure

## Data types

### <a name="sensubackend_url"></a>`Sensu::Backend_URL`

Sensu Backend URL's require protocol of ws:// or wss://.
A port is also required.
There is logic in sensu::agent class to add the protocol so it's optional.

Alias of

```puppet
Variant[Pattern[/^[^\s:]+:\d+$/], Pattern[/^ws:\/\/[^\s:]+:\d+$/], Pattern[/^wss:\/\/[^\s:]++:\d+$/]]
```

## Tasks

### <a name="agent_event"></a>`agent_event`

Create a Sensu Go agent event via the agent API

**Supports noop?** false

#### Parameters

##### `name`

Data type: `String[1]`

The name of the event

##### `status`

Data type: `Integer`

The event status

##### `output`

Data type: `String[1]`

The event output

##### `ttl`

Data type: `Optional[Integer]`

The event TTL

##### `port`

Data type: `Optional[Integer]`

The agent API port, defaults to 3031

### <a name="apikey"></a>`apikey`

Manage Sensu Go API keys

**Supports noop?** false

#### Parameters

##### `action`

Data type: `Enum[create,list,delete]`

The action to perform

##### `username`

Data type: `Optional[String[1]]`

The username for the API key. Required for action=create

##### `key`

Data type: `Optional[String[1]]`

The API key. Required for action=delete

### <a name="assets_outdated"></a>`assets_outdated`

Retreive outdated Sensu Go assets

**Supports noop?** false

#### Parameters

##### `namespace`

Data type: `Optional[String[1]]`

The namespace, defaults to all namespaces

### <a name="backend_upgrade"></a>`backend_upgrade`

Execute Sensu Go backend upgrade

**Supports noop?** false

#### Parameters

##### `config_file`

Data type: `Optional[String[1]]`

Path to backend.yml

##### `timeout`

Data type: `Optional[Integer]`

Timeout for connecting to etcd

##### `etcd_advertise_client_urls`

Data type: `Optional[Array]`

list of this member's client URLs to advertise to clients

##### `etcd_cert_file`

Data type: `Optional[String[1]]`

path to the client server TLS cert file

##### `etcd_cipher_suites`

Data type: `Optional[Array]`

list of ciphers to use for etcd TLS configuration

##### `etcd_client_cert_auth`

Data type: `Optional[Boolean]`

enable client cert authentication

##### `etcd_client_urls`

Data type: `Optional[Array]`

client URLs to use when operating as an etcd client

##### `etcd_key_file`

Data type: `Optional[String[1]]`

path to the client server TLS key file

##### `etcd_max_request_bytes`

Data type: `Optional[Integer]`

maximum etcd request size in bytes (use with caution)

##### `etcd_trusted_ca_file`

Data type: `Optional[String[1]]`

path to the client server TLS trusted CA cert file

### <a name="check_execute"></a>`check_execute`

Execute a Sensu Go check

**Supports noop?** false

#### Parameters

##### `check`

Data type: `String[1]`

The name of the check to execute

##### `subscription`

Data type: `Optional[String[1]]`

The subscription

##### `namespace`

Data type: `Optional[String[1]]`

The namespace, defaults to `default`

##### `reason`

Data type: `Optional[String[1]]`

Explanation for the creation of this entry.

### <a name="event"></a>`event`

Manage Sensu Go events

**Supports noop?** false

#### Parameters

##### `action`

Data type: `Enum[resolve,delete]`

The action to perform

##### `entity`

Data type: `String[1]`

The entity for event

##### `check`

Data type: `String[1]`

The check for event

##### `namespace`

Data type: `Optional[String[1]]`

The namespace for event

### <a name="install_agent"></a>`install_agent`

Install Sensu Go agent

**Supports noop?** false

#### Parameters

##### `backend`

Data type: `String[1]`

The backend(s) to connect agent to

##### `subscription`

Data type: `String[1]`

The subscription(s) for the agent

##### `entity_name`

Data type: `Optional[String[1]]`

The agent entity name

##### `namespace`

Data type: `Optional[String[1]]`

The namespace for the agent, default is 'default'

##### `output`

Data type: `Optional[Boolean]`

Return output from commands

### <a name="install_agent_linux"></a>`install_agent_linux`

Install Sensu Go agent on Linux

**Supports noop?** false

### <a name="install_agent_windows"></a>`install_agent_windows`

Install Sensu Go agent on Windows

**Supports noop?** false

### <a name="resolve_reference"></a>`resolve_reference`

Generate targets from Sensu Go

**Supports noop?** false

#### Parameters

##### `namespace`

Data type: `Optional[String[1]]`

Namespace to pull entities from

##### `subscription`

Data type: `Optional[String[1]]`

Find entities with this subscription

##### `interface_list`

Data type: `Optional[Array]`

Interfaces to search if more than one present

### <a name="silenced"></a>`silenced`

Manage Sensu Go silencings

**Supports noop?** false

#### Parameters

##### `action`

Data type: `Enum[create,update,delete]`

The action to perform

##### `subscription`

Data type: `Optional[String[1]]`

The subscription to silence

##### `check`

Data type: `Optional[String[1]]`

The check to silence

##### `namespace`

Data type: `Optional[String[1]]`

The namespace for silenced resources

##### `begin`

Data type: `Optional[Integer]`

Time at which silence entry goes into effect, in epoch.

##### `expire`

Data type: `Optional[Integer]`

Number of seconds until this entry should be deleted.

##### `expire_on_resolve`

Data type: `Optional[Boolean]`

If the entry should be deleted when a check begins return OK status (resolves).

##### `creator`

Data type: `Optional[String]`

Person/application/entity responsible for creating the entry.

##### `reason`

Data type: `Optional[String]`

Explanation for the creation of this entry.

